Started to rescind the name "skin", replacing it with "tool".  Did this in all
the places that normal users will see:

  - command line: --tool=foo (although --skin=foo still works)
  - docs: removed all traces (included renaming coregrind_skins.html to
    coregrind_tools.html)
  - in the usage messages
  - in error messages

Also did in in some places that I judged were unlikely to cause clashes with
existing workspaces:

  - in the header comments of many files (eg. "This file is part of Memcheck, a
    Valgrind tool for...")
  - in the regtests script
  - in the .supp files
  - in AUTHORS
  - in README_MISSING_SYSCALL_OR_IOCTL

Also update the AUTHORS file to mention Jeremy.


git-svn-id: svn://svn.valgrind.org/valgrind/trunk@2027 a5019735-40e9-0310-863c-91ae7b9d1cf9
diff --git a/memcheck/docs/mc_main.html b/memcheck/docs/mc_main.html
index aedef6e..b827693 100644
--- a/memcheck/docs/mc_main.html
+++ b/memcheck/docs/mc_main.html
@@ -7,13 +7,13 @@
 <a name="mc-top"></a>
 <h2>3&nbsp; <b>Memcheck</b>: a heavyweight memory checker</h2>
 
-To use this skin, you may specify <code>--skin=memcheck</code> on the
+To use this tool, you may specify <code>--tool=memcheck</code> on the
 Valgrind command line.  But you don't have to, since this is the
-default skin.
+default tool.
 
 <h3>3.1&nbsp; Kinds of bugs that memcheck can find</h3>
 
-Memcheck is Valgrind-1.0.X's checking mechanism bundled up into a skin.
+Memcheck is Valgrind-1.0.X's checking mechanism bundled up into a tool.
     All reads and writes of memory are checked, and calls to
     malloc/new/free/delete are intercepted. As a result, memcheck can
     detect the following problems:
@@ -382,7 +382,7 @@
 <pre>
 Memcheck:suppression_type
 </pre>
-Or, since some of the suppressions are shared with the Addrcheck skin:
+Or, since some of the suppressions are shared with Addrcheck:
 <pre>
 Memcheck,Addrcheck:suppression_type
 </pre>
@@ -772,7 +772,7 @@
 <h3>3.7&nbsp; Client Requests</h3>
 
 The following client requests are defined in <code>memcheck.h</code>.  They
-also work for the Addrcheck skin.  See <code>memcheck.h</code> for exact
+also work for Addrcheck.  See <code>memcheck.h</code> for exact
 details of their arguments.
 
 <ul>
diff --git a/memcheck/mac_leakcheck.c b/memcheck/mac_leakcheck.c
index a9b5ad2..5084075 100644
--- a/memcheck/mac_leakcheck.c
+++ b/memcheck/mac_leakcheck.c
@@ -5,8 +5,8 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
-   detecting memory errors, and AddrCheck, a lightweight Valgrind skin 
+   This file is part of MemCheck, a heavyweight Valgrind tool for
+   detecting memory errors, and AddrCheck, a lightweight Valgrind tool 
    for detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mac_malloc_wrappers.c b/memcheck/mac_malloc_wrappers.c
index 536cc2e..c9b2fca 100644
--- a/memcheck/mac_malloc_wrappers.c
+++ b/memcheck/mac_malloc_wrappers.c
@@ -5,8 +5,8 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
-   detecting memory errors, and AddrCheck, a lightweight Valgrind skin 
+   This file is part of MemCheck, a heavyweight Valgrind tool for
+   detecting memory errors, and AddrCheck, a lightweight Valgrind tool 
    for detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mac_needs.c b/memcheck/mac_needs.c
index 1fd0ef7..f90efb0 100644
--- a/memcheck/mac_needs.c
+++ b/memcheck/mac_needs.c
@@ -5,8 +5,8 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
-   detecting memory errors, and AddrCheck, a lightweight Valgrind skin 
+   This file is part of MemCheck, a heavyweight Valgrind tool for
+   detecting memory errors, and AddrCheck, a lightweight Valgrind tool 
    for detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mac_replace_strmem.c b/memcheck/mac_replace_strmem.c
index 06e6a57..6ae5800 100644
--- a/memcheck/mac_replace_strmem.c
+++ b/memcheck/mac_replace_strmem.c
@@ -6,7 +6,7 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mac_shared.h b/memcheck/mac_shared.h
index 3550ce8..70fbab1 100644
--- a/memcheck/mac_shared.h
+++ b/memcheck/mac_shared.h
@@ -5,8 +5,8 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
-   detecting memory errors, and AddrCheck, a lightweight Valgrind skin 
+   This file is part of MemCheck, a heavyweight Valgrind tool for
+   detecting memory errors, and AddrCheck, a lightweight Valgrind tool 
    for detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mc_clientreqs.c b/memcheck/mc_clientreqs.c
index 56d1773..ddfb05d 100644
--- a/memcheck/mc_clientreqs.c
+++ b/memcheck/mc_clientreqs.c
@@ -6,7 +6,7 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mc_constants.h b/memcheck/mc_constants.h
index 455175d..48f8509 100644
--- a/memcheck/mc_constants.h
+++ b/memcheck/mc_constants.h
@@ -4,7 +4,7 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mc_errcontext.c b/memcheck/mc_errcontext.c
index 1360dbe..5542581 100644
--- a/memcheck/mc_errcontext.c
+++ b/memcheck/mc_errcontext.c
@@ -5,7 +5,7 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mc_helpers.S b/memcheck/mc_helpers.S
index 681f049..f8ed6dc 100644
--- a/memcheck/mc_helpers.S
+++ b/memcheck/mc_helpers.S
@@ -5,7 +5,7 @@
 ##--------------------------------------------------------------------##
 
 /*
-  This file is part of MemCheck, a heavyweight Valgrind skin for
+  This file is part of MemCheck, a heavyweight Valgrind tool for
   detecting memory errors.
 
   Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mc_main.c b/memcheck/mc_main.c
index 9e82f39..52ad032 100644
--- a/memcheck/mc_main.c
+++ b/memcheck/mc_main.c
@@ -6,7 +6,7 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/mc_translate.c b/memcheck/mc_translate.c
index e88f442..249076c 100644
--- a/memcheck/mc_translate.c
+++ b/memcheck/mc_translate.c
@@ -5,7 +5,7 @@
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
diff --git a/memcheck/memcheck.h b/memcheck/memcheck.h
index 5db9900..5dc7c80 100644
--- a/memcheck/memcheck.h
+++ b/memcheck/memcheck.h
@@ -9,7 +9,7 @@
 
    ----------------------------------------------------------------
 
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2002-2003 Julian Seward.  All rights reserved.
diff --git a/memcheck/mc_from_ucode.c b/memcheck/mc_from_ucode.c
index dbf1747..e1f2877 100644
--- a/memcheck/mc_from_ucode.c
+++ b/memcheck/mc_from_ucode.c
@@ -1,11 +1,11 @@
 
 /*--------------------------------------------------------------------*/
 /*--- Generate code for skin-specific UInstrs.                     ---*/
 /*---                                              mc_from_ucode.c ---*/
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
@@ -1,11 +1,11 @@
 
 /*--------------------------------------------------------------------*/
-/*--- Generate code for skin-specific UInstrs.                     ---*/
+/*--- Generate code for tool-specific UInstrs.                     ---*/
 /*---                                              mc_from_ucode.c ---*/
 /*--------------------------------------------------------------------*/
diff --git a/memcheck/mc_include.h b/memcheck/mc_include.h
index 01414e2..69e1d6d 100644
--- a/memcheck/mc_include.h
+++ b/memcheck/mc_include.h
@@ -1,11 +1,11 @@
 
 /*--------------------------------------------------------------------*/
 /*--- A header file for all parts of the MemCheck skin.            ---*/
 /*---                                                 mc_include.h ---*/
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of MemCheck, a heavyweight Valgrind skin for
+   This file is part of MemCheck, a heavyweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
@@ -1,11 +1,11 @@
 
 /*--------------------------------------------------------------------*/
-/*--- A header file for all parts of the MemCheck skin.            ---*/
+/*--- A header file for all parts of the MemCheck tool.            ---*/
 /*---                                                 mc_include.h ---*/
 /*--------------------------------------------------------------------*/